# Installing Mods

There are basically two ways to install mods into BCML: GameBanana one-click or adding a manual
download. To use GameBanana one-click, go to GameBanana in your browser, find a mod you want, and 
click the BCML 1-Click Install button.

To install manually, click the floating action button on the Mods tab of the main BCML window.
(Though you can also drag-and-drop files onto the BCML window or double-click the mod in Windows).
This will open up the installation dialog. Click "Browse..." to select the mod(s) you wish to install. 
BCML supports two kinds of mods: graphic packs (Cemu/Wii U only) and BNPs (Cemu/Wii U/Switch). When
browsing for mods, you can either select a packaged mod (BNP, ZIP, 7z, or RAR file) or select the 
meta file (`info.json` or `rules.txt`) in an unzipped mod folder.

You can add as many mods as you wish to the installation dialog and sort them how you like. Note 
that, regardless of how you sort your main mod list, the install dialog sorts mods in the order that
it will install them. This means the last mod on the list will be the last one installed and will 
take priority over the others.

The install dialog also contains an overflow menu with advanced install options. If you know exactly
what you're doing, you can use these to customize the installation of a mod, but in most cases you
should only use these options if instructed by a mod creator.

When you have added all of the mods you want to install, click "Install" or "Queue." Clicking
"Install" will immediately proceed to install them, starting at the end of your current load order.
"Queue" will add them temporarily to your mod list, where you can sort them however you may need
before clicking "Apply" to install and sort your mods.
